@@ -1,7 +1,7 @@
 #!/bin/sh
 echo "Texmaker compilation :"
 echo "----------------------------------------"
-echo "Enter path to QT4 (/usr/lib/qt4 or ...):"
+echo "Enter path to QT:"
 read QTDIR
 echo "Enter SYSTEM (1: UNIX ; 2: MACOSX) :"
 read SYSTEM
@@ -17,17 +17,16 @@ echo "Enter  DIRECTORY for the desktop file (/usr/share/applications) :"
 read DESKTOPDIR
 echo "Enter  DIRECTORY for the icon file (/usr/share/pixmaps) :"
 read ICONDIR
-qmake -unix PREFIX=$PREFIX DESKTOPDIR=$DESKTOPDIR ICONDIR=$ICONDIR texmaker.pro
+$QTDIR/bin/qmake PREFIX=$PREFIX DESKTOPDIR=$DESKTOPDIR ICONDIR=$ICONDIR texmaker.pro
 make
 make install
 echo "Compilation and installation done"
-# set the -spec option, if necessary. Ex : qmake -unix -spec linux-g++ PREFIX=$PREFIX texmaker.pro
 exit 0
 fi
 
 if [ "$SYSTEM" = 2 ] 
 then
-qmake -macx -spec macx-g++ texmaker.pro
+$QTDIR/bin/qmake -macx -spec macx-g++ texmaker.pro
 make
 make install
 echo "Compilation and installation done"
