@@ -14,7 +14,7 @@
 #include <QFrame>
 #include <QTextDocument>
 #include <QTextCursor>
-//#include <QTextEdit>
+#include <QLineEdit>
 #include <QTextBlock>
 
 LatexEditorView::LatexEditorView(QWidget *parent,QFont & efont,bool line,QList<QColor> edcolors, QList<QColor> hicolors,bool inlinespelling,QString ignoredWords,Hunspell *spellChecker,bool tabspaces, int tabwidth,const QKeySequence viewfocus,QString name,QStringList ulist) : QWidget(parent)
@@ -66,12 +66,15 @@ findwidget->SetEditor(editor);
 connect(findwidget, SIGNAL( requestHide() ), Stack, SLOT( hide() ) );
 connect(findwidget, SIGNAL( requestExtension() ), this, SLOT( updateFind() ) );
 
+
 replacewidget=new ReplaceWidget(Stack);
 Stack->addWidget(replacewidget);
 replacewidget->SetEditor(editor);
 connect(replacewidget, SIGNAL( requestHide() ), Stack, SLOT( hide() ) );
 connect(replacewidget, SIGNAL( requestExtension() ), this, SLOT( updateReplace() ) );
 
+connect(editor,SIGNAL(textChanged()), this, SLOT( updateInSelection() ) );
+
 gotolinewidget=new GotoLineWidget(Stack);
 Stack->addWidget(gotolinewidget);
 gotolinewidget->SetEditor(editor);
@@ -190,4 +193,9 @@ gotolinewidget->ui.spinLine->setMaximum(editor->numoflines() );
 gotolinewidget->ui.spinLine->selectAll();
 }
 
+void LatexEditorView::updateInSelection()
+{
+findwidget->ui.checkSelection->setChecked( false );
+}
+
 
