@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -11,31 +11,15 @@
 
 #ifndef LETTERDIALOG_H
 #define LETTERDIALOG_H
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qdialog.h>
 
+#include "ui_letterdialog.h"
 
-class letterdialog : public QDialog  {
+class LetterDialog : public QDialog  {
    Q_OBJECT
 public:
-	letterdialog(QWidget *parent=0, const char *name=0);
-	~letterdialog();
-
-public:
-	QLabel *QLabel_2;
-	QLabel *QLabel_3;
-	QLabel *QLabel_4;
-
-  QComboBox *combo2;
-  QComboBox *combo3;
-  QComboBox *combo4;
-  QCheckBox* checkbox1;
-	QPushButton *buttonOk;
-	QPushButton *buttonCancel;
+	LetterDialog(QWidget *parent=0, const char *name=0);
+	~LetterDialog();
+	Ui::LetterDialog ui;
 
 };
 
