@@ -10,6 +10,9 @@
  ***************************************************************************/
 
 #include "lightfindwidget.h"
+
+#include <QDebug>
+#include <QTextCursor>
 #include <QMessageBox>
 
 LightFindWidget::LightFindWidget(QWidget* parent)
@@ -25,7 +28,9 @@ ui.closeButton->setToolTip("Escape");
 ui.moreButton->setCheckable(true);
 ui.moreButton->setAutoDefault(false);
 connect(ui.moreButton, SIGNAL(toggled(bool)), this, SLOT(expand(bool)));
-ui.checkRegExp->setChecked( FALSE );
+ui.checkRegExp->setChecked( false );
+ui.checkSelection->setChecked( false );
+connect(ui.checkSelection, SIGNAL(toggled(bool)), this, SLOT(updateSelection(bool)));
 ui.extension->hide();
 updateGeometry();
  }
@@ -37,7 +42,12 @@ LightFindWidget::~LightFindWidget()
 
 void LightFindWidget::doFind()
 {
-if ( !editor ) return;
+if ( !editor )
+  {
+  startpos=-1; 
+  endpos=-1;
+  return;
+  }
 if (ui.checkRegExp->isChecked())
   {
   QRegExp regex(ui.comboFind->currentText());
@@ -47,16 +57,33 @@ if (ui.checkRegExp->isChecked())
     return;
     }
   }
-if ( !editor->search( ui.comboFind->currentText(), ui.checkCase->isChecked(),	ui.checkWords->isChecked(), ui.radioForward->isChecked(), !ui.checkBegin->isChecked(),ui.checkRegExp->isChecked() ) )
-   {
-   ui.checkBegin->setChecked( TRUE );
-   }
-else ui.checkBegin->setChecked( FALSE );
+int result=-1;  
+if (ui.checkSelection->isChecked())
+  {
+  if ((startpos>-1) && (endpos>-1)) 
+	{
+	result=editor->searchInSelection( ui.comboFind->currentText(), ui.checkCase->isChecked(),ui.checkWords->isChecked(), ui.checkRegExp->isChecked(),startpos,endpos); 
+	if (result>-1) startpos=result;
+	else ui.checkSelection->setChecked( false );  
+	}
+  }
+else
+  {
+  startpos=-1; 
+  endpos=-1;
+  if ( !editor->search( ui.comboFind->currentText(), ui.checkCase->isChecked(),	ui.checkWords->isChecked(), ui.radioForward->isChecked(), !ui.checkBegin->isChecked(),ui.checkRegExp->isChecked()) )
+    {
+    ui.checkBegin->setChecked( true );
+    }
+  else ui.checkBegin->setChecked( false );
+  }
 editor->viewport()->repaint();
 }
 
 void LightFindWidget::doHide()
 {
+startpos=-1; 
+endpos=-1;
 emit requestHide();
 if ( editor ) 
 	{
@@ -73,8 +100,42 @@ editor=ed;
 void LightFindWidget::expand(bool e)
 {
  ui.extension->setVisible(e);
- if (!e) ui.checkRegExp->setChecked( FALSE );
+ if (!e) 
+    {
+    ui.checkRegExp->setChecked( false );
+    ui.checkSelection->setChecked( false );
+    }
  updateGeometry();
  emit requestExtension();
  editor->viewport()->repaint();
 }
+
+void LightFindWidget::updateSelection(bool e)
+{
+ui.checkBegin->setEnabled(!e);
+if (e) ui.radioForward->setChecked(true);
+if ( !editor ) 
+  {
+  startpos=-1; 
+  endpos=-1;
+  }
+else if (e)
+  {
+  QTextCursor c=editor->textCursor();
+  if (c.hasSelection()) 
+	{
+	startpos=c.selectionStart();
+	endpos=c.selectionEnd();
+	}
+  else
+	{
+	startpos=-1; 
+	endpos=-1;
+	}
+  }
+else
+  {
+  startpos=-1; 
+  endpos=-1;
+  }
+}
