@@ -157,7 +157,7 @@ while (i < text.length())
 	case StateStandard: {
 		tmp=text.at( i );
 		if (tmp=='\\') {
-			if (next=='[')
+			if (next=='[' || next=='(')
 				{
 				setFormat( i, 1,ColorMath );
 				blockData->code[i]=1;
@@ -324,7 +324,7 @@ while (i < text.length())
 				}
 		buffer = QString::null;
 		} else if (tmp== '\\') {
-			if (next==']')
+			if (next==']' || next==')')
 				{
 				setFormat( i, 1,ColorMath);
 				blockData->code[i]=1;
@@ -474,21 +474,11 @@ while (i < text.length())
 				state=StateGraphicMath;
 				}
 		} else
-		if (tmp== '{' ){
+			{
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicMath;
-		} else
-		if (tmp== '}' ){
-			setFormat( i, 1,ColorMath);
-			blockData->code[i]=1;
-			state=StateGraphicMath;
-		} else
-		 {
-			setFormat( i, 1,ColorMath);
-			blockData->code[i]=1;
-			state=StateGraphicMath;
-		}
+			}
 	buffer = QString::null;
 	} break;
 	case StateGraphicAsyMath: {
@@ -530,21 +520,11 @@ while (i < text.length())
 				state=StateGraphicAsyMath;
 				}
 		} else
-		if (tmp== '{' ){
+			{
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicAsyMath;
-		} else
-		if (tmp== '}' ){
-			setFormat( i, 1,ColorMath);
-			blockData->code[i]=1;
-			state=StateGraphicAsyMath;
-		} else
-		 {
-			setFormat( i, 1,ColorMath);
-			blockData->code[i]=1;
-			state=StateGraphicAsyMath;
-		}
+			}
 	buffer = QString::null;
 	} break;
 	case StateCommand:{
@@ -755,18 +735,9 @@ while (i < text.length())
 		verbflag=' ';
 		} else
 		if (tmp=='$') {
-			if (last=='\\')
-				{
 				setFormat( i, 1,ColorVerbatim);
 				blockData->code[i]=1;
 				state=StateVerbatim;
-				}
-			else
-				{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateVerbatim;
-				}
 		} else
 		if (tmp=='%') {
 			if (last=='\\')
@@ -792,18 +763,8 @@ while (i < text.length())
 		} else
 		if (tmp=='\\' || tmp==',' || tmp==';' || /*tmp=='\'' ||*/ tmp=='\"' || tmp=='`' || tmp=='^' || tmp=='~') {
 			blockData->code[i]=1;
-			if (last=='\\')
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateVerbatim;
-			}
-			else
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateVerbatim;
-			}
+			setFormat( i, 1,ColorVerbatim);
+			state=StateVerbatim;
 		} else
 	     		{
          		setFormat( i, 1,ColorVerbatim);
@@ -1045,18 +1006,9 @@ while (i < text.length())
 	case StateGraphicCommand:{
 		tmp=text.at( i );
 		if (tmp=='$') {
-			if (last=='\\')
-				{
 				setFormat( i, 1,ColorVerbatim);
 				blockData->code[i]=1;
 				state=StateGraphic;
-				}
-			else
-				{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateGraphic;
-				}
 		} else
 		if (tmp=='%') {
 			if (last=='\\')
@@ -1082,18 +1034,8 @@ while (i < text.length())
 		} else
 		if (tmp=='\\' || tmp==',' || tmp==';' || /*tmp=='\'' ||*/ tmp=='\"' || tmp=='`' || tmp=='^' || tmp=='~') {
 			blockData->code[i]=1;
-			if (last=='\\')
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateGraphic;
-			}
-			else
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateGraphic;
-			}
+			setFormat( i, 1,ColorVerbatim);
+			state=StateGraphic;
 		} else
 	     		{
          		setFormat( i, 1,ColorVerbatim);
@@ -1104,18 +1046,9 @@ while (i < text.length())
 	case StateGraphicAsyCommand:{
 		tmp=text.at( i );
 		if (tmp=='$') {
-			if (last=='\\')
-				{
 				setFormat( i, 1,ColorVerbatim);
 				blockData->code[i]=1;
 				state=StateGraphicAsy;
-				}
-			else
-				{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateGraphicAsy;
-				}
 		} else
 		if (tmp=='%') {
 			if (last=='\\')
@@ -1141,18 +1074,8 @@ while (i < text.length())
 		} else
 		if (tmp=='\\' || tmp==',' || tmp==';' || /*tmp=='\'' ||*/ tmp=='\"' || tmp=='`' || tmp=='^' || tmp=='~') {
 			blockData->code[i]=1;
-			if (last=='\\')
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateGraphicAsy;
-			}
-			else
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateGraphicAsy;
-			}
+			setFormat( i, 1,ColorVerbatim);
+			state=StateGraphicAsy;
 		} else
 	     		{
          		setFormat( i, 1,ColorVerbatim);
@@ -1289,18 +1212,9 @@ while (i < text.length())
 	case StateSweaveCommand:{
 		tmp=text.at( i );
 		if (tmp=='$') {
-			if (last=='\\')
-				{
 				setFormat( i, 1,ColorVerbatim);
 				blockData->code[i]=1;
 				state=StateSweave;
-				}
-			else
-				{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateSweave;
-				}
 		} else
 		if (tmp=='%') {
 			if (last=='\\')
@@ -1326,18 +1240,8 @@ while (i < text.length())
 		} else
 		if (tmp=='\\' || tmp==',' || tmp==';' /*|| tmp=='\''*/ || tmp=='\"' || tmp=='`' || tmp=='^' || tmp=='~') {
 			blockData->code[i]=1;
-			if (last=='\\')
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateSweave;
-			}
-			else
-			{
-				setFormat( i, 1,ColorVerbatim);
-				blockData->code[i]=1;
-				state=StateSweave;
-			}
+			setFormat( i, 1,ColorVerbatim);
+			state=StateSweave;
 		} else
 	     		{
          		setFormat( i, 1,ColorVerbatim);
@@ -1569,16 +1473,6 @@ while (i < text.length())
 				blockData->code[i]=1;
 				state=StateGraphicMath;
 				}
-		} else
-		if (tmp== '{' ){
-			setFormat( i, 1,ColorMath);
-			blockData->code[i]=1;
-			state=StateGraphicMath;
-		} else
-		if (tmp== '}' ){
-			setFormat( i, 1,ColorMath);
-			blockData->code[i]=1;
-			state=StateGraphicMath;
 		} else
 		 {
 			setFormat( i, 1,ColorMath);
@@ -1634,12 +1528,12 @@ while (i < text.length())
 			state=StateGraphicComment;
 			blockData->code[i]=1;
 			buffer = QString::null;
-		} else
-		if (tmp== '%' ){
-			setFormat( i, 1,ColorComment);
-			state=StateGraphicComment;
-			blockData->code[i]=1;
-			buffer = QString::null;
+// 		} else
+// 		if (tmp== '%' ){
+// 			setFormat( i, 1,ColorComment);
+// 			state=StateGraphicComment;
+// 			blockData->code[i]=1;
+// 			buffer = QString::null;
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -1682,18 +1576,9 @@ while (i < text.length())
 	case StateGraphicCommand:{
 		tmp=text.at( i );
 		if (tmp=='$') {
-			if (last=='\\')
-				{
 				setFormat( i, 1,ColorStandard);
 				blockData->code[i]=1;
 				state=StateGraphic;
-				}
-			else
-				{
-				setFormat( i, 1,ColorStandard);
-				blockData->code[i]=1;
-				state=StateGraphic;
-				}
 		} else
 		if (tmp=='%') {
 			if (last=='\\')
@@ -1719,18 +1604,8 @@ while (i < text.length())
 		} else
 		if (tmp=='\\' || tmp==',' || tmp==';' || /*tmp=='\'' ||*/ tmp=='\"' || tmp=='`' || tmp=='^' || tmp=='~') {
 			blockData->code[i]=1;
-			if (last=='\\')
-			{
-				setFormat( i, 1,ColorStandard);
-				blockData->code[i]=1;
-				state=StateGraphic;
-			}
-			else
-			{
-				setFormat( i, 1,ColorStandard);
-				blockData->code[i]=1;
-				state=StateGraphic;
-			}
+			setFormat( i, 1,ColorStandard);
+			state=StateGraphic;
 		} else
 	     		{
          		setFormat( i, 1,ColorStandard);
