@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,9 +12,10 @@
 #ifndef __linenumberwidget_h
 #define __linenumberwidget_h
 
-#include <qwidget.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <QtGui>
+#include <QWidget>
+#include <QFont>
+#include <QPaintEvent>
 #include "latexeditor.h"
 
 
@@ -22,21 +23,23 @@ class LineNumberWidget: public QWidget
 {
     Q_OBJECT
 public:
-    LineNumberWidget(LatexEditor*, QWidget* =0, const char* =0);
+    LineNumberWidget(LatexEditor*, QWidget* parent);
     virtual ~LineNumberWidget();
 
 public slots:
-    void doRepaint() { repaint( FALSE ); }
+    void doRepaint() { repaint(); }
     void setFont(QFont efont);
+    void setRange(int s, int e);
 
 protected:
-    virtual void resizeEvent( QResizeEvent* );
-    virtual void paintEvent( QPaintEvent* );
+    virtual bool event(QEvent *event);
+    virtual void paintEvent( QPaintEvent* event);
+    virtual void mousePressEvent(QMouseEvent *e);
 
 private:
     LatexEditor* m_editor;
     QFont numfont;
-    QPixmap buffer;
+    int start, end;
 };
 
 #endif // __linenumberwidget_h
