@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2011 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -11,49 +11,22 @@
 
 #ifndef QUICKDOCUMENTDIALOG_H
 #define QUICKDOCUMENTDIALOG_H
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qlineedit.h>
-#include <qstringlist.h>
+
+#include "ui_quickdocumentdialog.h"
 #include "addoptiondialog.h"
 
 
 
-/**
-  *@author Brachet Pascal
-  */
-
-class quickdocumentdialog : public QDialog  {
+class QuickDocumentDialog : public QDialog  {
    Q_OBJECT
 public:
-	quickdocumentdialog(QWidget *parent=0, const char *name=0);
-	~quickdocumentdialog();
+	QuickDocumentDialog(QWidget *parent=0, const char *name=0);
+	~QuickDocumentDialog();
+	Ui::QuickDocumentDialog ui;
 
 public:
-	QLabel *QLabel_1;
-	QLabel *QLabel_2;
-	QLabel *QLabel_3;
-	QLabel *QLabel_4;
-  QLabel *QLabel_5;
-  QLabel *QLabel_6;
-  QLabel *QLabel_7;
-  QLineEdit *LineEdit1,*LineEdit2 ;
-  QComboBox *combo1;
-  QComboBox *combo2;
-  QComboBox *combo3;
-  QComboBox *combo4;
-  QCheckBox* checkbox1, *checkbox2;
-	QPushButton *buttonOk;
-	QPushButton *buttonCancel;
-	QPushButton *userClassBtn, *userPaperBtn, *userEncodingBtn, *userOptionsBtn;
 
-  QListBox *availableBox;
-  QStringList otherClassList, otherPaperList, otherEncodingList, otherOptionsList;
+  QStringList otherClassList, otherPaperList, otherEncodingList, otherOptionsList, otherBabelList;
 
 public slots:
     void Init();
@@ -62,6 +35,7 @@ private slots:
     void addUserPaper();
     void addUserEncoding();
     void addUserOptions();
+    void addUserBabel();
 private :
 AddOptionDialog *dlg;
 };
