@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -13,32 +13,16 @@
 #ifndef STRUCTDIALOG_H
 #define STRUCTDIALOG_H
 
-
-/**
-  *@author Pascal Brachet
-  */
-
-#include <qwidget.h>
-#include <qlineedit.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qcheckbox.h>
-#include <qdialog.h>
+#include "ui_structdialog.h"
 
 
-class structdialog : public QDialog  {
+class StructDialog : public QDialog  {
    Q_OBJECT
 public:
-	structdialog(QWidget *parent=0, const char *name=0);
-	~structdialog();
+	StructDialog(QWidget *parent=0, QString name="");
+	~StructDialog();
+	Ui::StructDialog ui;
 
-public:
-	QLabel *QLabel_1;
-  QLineEdit* title_edit;
-  QCheckBox* checkbox;
-	QPushButton *buttonOk;
-	QPushButton *buttonCancel;
-private:
 };
 
 #endif
